@@ -7,7 +7,7 @@ use warnings FATAL => 'all';
 ###########################################################################
 
 { package Muldis::DB::Interface; # module
-    use version; our $VERSION = qv('0.6.1');
+    use version; our $VERSION = qv('0.6.2');
     # Note: This given version applies to all of this file's packages.
 
     use Carp;
@@ -320,7 +320,7 @@ Common public API for Muldis DB Engines
 
 =head1 VERSION
 
-This document describes Muldis::DB::Interface version 0.6.1 for Perl 5.
+This document describes Muldis::DB::Interface version 0.6.2 for Perl 5.
 
 It also describes the same-number versions for Perl 5 of
 Muldis::DB::Interface::Machine ("Machine"), Muldis::DB::Interface::Process
@@ -338,7 +338,7 @@ a third Perl variable holding the relation data of the result.
 
     my $machine = Muldis::DB::Interface::new_machine({
         'engine_name' => 'Muldis::DB::Engine::Example',
-        'exp_ast_lang' => [ 'MuldisD', 'cpan:DUNCAND', '0.8.1' ],
+        'exp_ast_lang' => [ 'Muldis_D', 'cpan:DUNCAND', '0.8.1' ],
         'machine_config' => {},
     });
     my $process = $machine->new_process();
@@ -407,7 +407,7 @@ separate L<Muldis::DB::Cookbook> distribution (when that comes to exist).
 
 B<Muldis::DB::Interface>, aka I<Interface>, comprises the minimal core of
 the Muldis DB framework, the one component that probably every program
-would use.  Together with the Muldis D language (see L<Language::MuldisD>),
+would use.  Together with the Muldis D language (see L<Muldis::D>),
 it defines the common API for Muldis DB implementations to do and which
 applications invoke.
 
@@ -487,9 +487,9 @@ Muldis D (or alternative) language version that its invocant C<Machine>
 object and its associated/child objects expect their AST/code/value input
 to conform to, and that their AST/code/value output will conform to.  The 3
 elements of the array (each a Str) are, in order, the language spec base
-name (typically C<MuldisD>), the language spec authority (typically
-C<cpan:DUNCAND> when the base name is C<MuldisD>), and the language spec
-version number (looks like C<1.2.3> for C<MuldisD> plus C<cpan:DUNCAND>).
+name (typically C<Muldis_D>), the language spec authority (typically
+C<cpan:DUNCAND> when the base name is C<Muldis_D>), and the language spec
+version number (looks like C<1.2.3> for C<Muldis_D> plus C<cpan:DUNCAND>).
 
 =item C<store_exp_ast_lang (Array :$lang!)>
 
@@ -640,15 +640,13 @@ This method returns the declared Muldis D type of its invocant C<Var>.
 =item C<fetch_ast of Array ()>
 
 This method returns the current Muldis D value of its invocant C<Var> as a
-Perl Hosted Abstract Muldis D data structure (whose root node is a Perl
-Array).
+Perl Hosted Data Muldis D data structure (whose root node is a Perl Array).
 
 =item C<store_ast (Array :$ast!)>
 
 This method assigns a new Muldis D value to its invocant C<Var>, which is
 supplied in the C<$ast> argument; the argument is expected to be a valid
-Perl Hosted Abstract Muldis D data structure (whose root node is a Perl
-Array).
+Perl Hosted Data Muldis D data structure (whose root node is a Perl Array).
 
 =back
 
@@ -843,6 +841,10 @@ Muldis DB is Copyright © 2002-2008, Darren Duncan.
 
 See the LICENSE AND COPYRIGHT of L<Muldis::DB> for details.
 
+=head1 TRADEMARK POLICY
+
+The TRADEMARK POLICY in L<Muldis::DB> applies to this file too.
+
 =head1 ACKNOWLEDGEMENTS
 
 The ACKNOWLEDGEMENTS in L<Muldis::DB> apply to this file too.
